<?php

/**
 * @package  Accept Payments WP
 */

namespace AcceptPaymentsWPInc;

final class Init
{
	/**
	 * Store all the classes inside an array.
	 * @return array Full list of classes.
	 */
	public static function get_services()
	{

		return [
			new Core\AcceptPaymentsWPAssets(),
			new Core\AcceptPaymentsWPSettingsLinks(),
			new Core\PaymentFormsController(),
			new Core\Admin\AcceptPaymentsWPAdmin()
		];
	}

	/**
	 * Loop through the classes, initialize them,
	 * and call the register() method if it exists.
	 */
	public static function register_services()
	{
		foreach ( self::get_services() as $class ) {
			$service = self::instantiate( $class );
			if ( method_exists( $service, 'register' ) ) {
				$service->register();
			}
		}
	}

	/**
	 * Initialize the class.
     *
	 * @param  class    $class    class from the services array.
	 * @return class    instance  new instance of the class.
	 */
	private static function instantiate( $class )
	{
		$service = new $class();

		return $service;
	}
}
